@@ -29,7 +29,7 @@
 #include <bonobo/bonobo-moniker-util.h>
 #include "gda-marshal.h"
 
-#define PARENT_TYPE BONOBO_X_OBJECT_TYPE
+#define PARENT_TYPE BONOBO_OBJECT_TYPE
 
 struct _GdaClientPrivate {
 	GHashTable *providers;
@@ -160,7 +160,7 @@ gda_client_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-BONOBO_X_TYPE_FUNC_FULL (GdaClient,
+BONOBO_TYPE_FUNC_FULL (GdaClient,
 			 GNOME_Database_Client,
 			 PARENT_TYPE,
 			 gda_client)
@@ -210,6 +210,22 @@ gda_client_open_connection (GdaClient *client,
 
 	/* try to find provider in our hash table */
 	corba_provider = g_hash_table_lookup (client->priv->providers, dsn_info->provider);
+	if (corba_provider) {
+		/* ping the provider object */
+		if (!bonobo_unknown_ping (corba_provider, NULL)) {
+			gpointer orig_key, orig_data;
+
+			if (g_hash_table_lookup_extended (client->priv->providers,
+							  dsn_info->provider,
+							  &orig_key, &orig_data)) {
+				g_hash_table_remove (client->priv->providers, dsn_info->provider);
+				free_hash_provider (orig_key, orig_data, NULL);
+			}
+
+			corba_provider = CORBA_OBJECT_NIL;
+		}
+	}
+
 	if (!corba_provider) {
 		/* not found, so load the new provider */
 		CORBA_exception_init (&ev);
@@ -243,7 +259,7 @@ gda_client_open_connection (GdaClient *client,
 
 	CORBA_exception_free (&ev);
 
-	cnc = gda_connection_new (client, corba_cnc, dsn_info->cnc_string,
+	cnc = gda_connection_new (client, corba_cnc, dsn,
 				  username ? username : "", password ? password : "");
 
 	if (!GDA_IS_CONNECTION (cnc)) {
@@ -296,14 +312,14 @@ gda_client_find_connection (GdaClient *client,
 	}
 
 	for (l = client->priv->connections; l; l = l->next) {
-		const gchar *tmp_str, *tmp_usr, *tmp_pwd;
+		const gchar *tmp_dsn, *tmp_usr, *tmp_pwd;
 
 		cnc = GDA_CONNECTION (l->data);
-		tmp_str = gda_connection_get_string (cnc);
+		tmp_dsn = gda_connection_get_dsn (cnc);
 		tmp_usr = gda_connection_get_username (cnc);
 		tmp_pwd = gda_connection_get_password (cnc);
 
-		if (((!tmp_str && !dsn_info->cnc_string) || !strcmp (tmp_str, dsn_info->cnc_string)) &&
+		if (((!tmp_dsn && !dsn_info->cnc_string) || !strcmp (tmp_dsn, dsn_info->cnc_string)) &&
 		    ((!tmp_usr && !username) || !strcmp (tmp_usr, username)) &&
 		    ((!tmp_pwd && !password) || !strcmp (tmp_pwd, password))) {
 			gda_config_free_data_source_info (dsn_info);
