@@ -23,6 +23,8 @@
  */
 
 #include <bonobo/bonobo-i18n.h>
+#include <stdlib.h>
+#include "gda-mysql.h"
 #include "gda-mysql-recordset.h"
 
 #define OBJECT_DATA_RECSET_HANDLE "GDA_Mysql_RecsetHandle"
