@@ -23,6 +23,7 @@
 
 #include "gda-postgres.h"
 #include "gda-postgres-provider.h"
+#include <stdlib.h>
 
 static void gda_postgres_provider_class_init (GdaPostgresProviderClass *klass);
 static void gda_postgres_provider_init       (GdaPostgresProvider *provider,
@@ -199,7 +200,6 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider,
 	GList *type_list;
 	PGconn *pconn;
 	PGresult *pg_res;
-	GdaError *error;
 
 	GdaPostgresProvider *pg_prv = (GdaPostgresProvider *) provider;
 
@@ -271,7 +271,7 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider,
 	return TRUE;
 }
 
-void
+static void
 free_type_list (gpointer data, gpointer user_data)
 {
 	GdaPostgresTypeDataPrivate *priv_td;
@@ -305,7 +305,8 @@ gda_postgres_provider_close_connection (GdaServerProvider *provider, GdaServerCo
 }
 
 static GList *
-process_sql_commands (GList *reclist, GdaServerConnection *cnc, const gchar *sql)
+process_sql_commands (GList *reclist, GdaServerConnection *cnc,
+		      const gchar *sql, GdaCommandOptions options)
 {
 	GdaPostgresConnectionPrivate *priv_data;
 	PGconn *pconn;
@@ -339,11 +340,15 @@ process_sql_commands (GList *reclist, GdaServerConnection *cnc, const gchar *sql
 			} 
 			
 			status = PQresultStatus(pg_res);
-			if (status == PGRES_TUPLES_OK ||
+			if (options & GDA_COMMAND_OPTION_IGNORE_ERRORS	||
+			    status == PGRES_TUPLES_OK 			||
 			    status == PGRES_COMMAND_OK) {
 				recset = gda_postgres_recordset_new (cnc, pg_res);
-				if (GDA_IS_SERVER_RECORDSET (recset))
+				if (GDA_IS_SERVER_RECORDSET (recset)) {
+					gda_server_recordset_set_command_text (recset, arr[n]);
+					gda_server_recordset_set_command_type (recset, GDA_COMMAND_TYPE_SQL);
 					reclist = g_list_append (reclist, recset);
+				}
 			} else {
 				gda_server_connection_add_error (
 					cnc, gda_postgres_make_error (pconn));
@@ -372,20 +377,24 @@ gda_postgres_provider_execute_command (GdaServerProvider *provider,
 	GList *reclist = NULL;
 	gchar *str;
 	GdaPostgresProvider *pg_prv = (GdaPostgresProvider *) provider;
+	GdaCommandOptions options;
 
 	g_return_val_if_fail (GDA_IS_POSTGRES_PROVIDER (pg_prv), NULL);
 	g_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), NULL);
 	g_return_val_if_fail (cmd != NULL, NULL);
 
+	options = gda_command_get_options (cmd);
 	switch (gda_command_get_command_type (cmd)) {
 	case GDA_COMMAND_TYPE_SQL :
-		reclist = process_sql_commands (reclist, cnc, gda_command_get_text (cmd));
+		reclist = process_sql_commands (reclist, cnc, gda_command_get_text (cmd),
+						options);
 		break;
 	case GDA_COMMAND_TYPE_TABLE :
 		str = g_strdup_printf ("SELECT * FROM %s", gda_command_get_text (cmd));
-		reclist = process_sql_commands (reclist, cnc, str);
+		reclist = process_sql_commands (reclist, cnc, str, options);
 		g_free (str);
 		break;
+	default:
 	}
 
 	return reclist;
@@ -488,7 +497,8 @@ get_postgres_procedures (GdaServerConnection *cnc, GdaParameterList *params)
 	g_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), NULL);
 
 	reclist = process_sql_commands (NULL, cnc, 
-			"SELECT proname FROM pg_proc ORDER BY proname");
+			"SELECT proname FROM pg_proc ORDER BY proname",
+			GDA_COMMAND_OPTION_STOP_ON_ERRORS);
 
 	if (!reclist)
 		return NULL;
@@ -509,7 +519,8 @@ get_postgres_tables (GdaServerConnection *cnc, GdaParameterList *params)
 
 	reclist = process_sql_commands (NULL, cnc, 
 			"SELECT relname FROM pg_class WHERE relkind = 'r' AND "
-			"relname !~ '^pg_' ORDER BY relname");
+			"relname !~ '^pg_' ORDER BY relname",
+			GDA_COMMAND_OPTION_STOP_ON_ERRORS);
 
 	if (!reclist)
 		return NULL;
@@ -576,7 +587,30 @@ get_postgres_views (GdaServerConnection *cnc, GdaParameterList *params)
 
 	reclist = process_sql_commands (NULL, cnc, 
 			"SELECT relname FROM pg_class WHERE relkind = 'v' AND "
-			"relname !~ '^pg_' ORDER BY relname");
+			"relname !~ '^pg_' ORDER BY relname",
+			GDA_COMMAND_OPTION_STOP_ON_ERRORS);
+
+	if (!reclist)
+		return NULL;
+
+	recset = GDA_SERVER_RECORDSET (reclist->data);
+	g_list_free (reclist);
+
+	return recset;
+}
+
+static GdaServerRecordset *
+get_postgres_indexes (GdaServerConnection *cnc, GdaParameterList *params)
+{
+	GList *reclist;
+	GdaServerRecordset *recset;
+
+	g_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), NULL);
+
+	reclist = process_sql_commands (NULL, cnc, 
+			"SELECT relname FROM pg_class WHERE relkind = 'i' AND "
+			"relname !~ '^pg_' ORDER BY relname",
+			GDA_COMMAND_OPTION_STOP_ON_ERRORS);
 
 	if (!reclist)
 		return NULL;
@@ -606,6 +640,8 @@ gda_postgres_provider_get_schema (GdaServerProvider *provider,
 		return get_postgres_types (cnc, params);
 	case GNOME_Database_Connection_SCHEMA_VIEWS :
 		return get_postgres_views (cnc, params);
+	case GNOME_Database_Connection_SCHEMA_INDEXES :
+		return get_postgres_indexes (cnc, params);
 	}
 
 	return NULL;
